#
# spec file for package qore
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014 David Nichols <david@qore.org>
# Copyright (c) 2014 Petr Vanek <petr@yarpen.cz>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?_datarootdir: %global mydatarootdir %_datarootdir}
%{!?_datarootdir: %global mydatarootdir /usr/share}

%if 0%{?sles_version}
%global dist .sles%{?sles_version}
%else
%if 0%{?suse_version}
# get *suse release major version
%global os_maj %(echo %suse_version|rev|cut -b3-|rev)
# get *suse release minor version without trailing zeros
%global os_min %(echo %suse_version|rev|cut -b-2|rev|sed s/0*$//)
%if %suse_version > 1010
%global dist .opensuse%{os_maj}_%{os_min}
%else
%global dist .suse%{os_maj}_%{os_min}
%endif
%endif
%endif

%define so_ver 12
%define module_dir %{_libdir}/qore-modules
%global user_module_dir %{mydatarootdir}/qore-modules/
%global libname libqore12
Name:           qore
Version:        1.19.2
Release:        1.3
Summary:        Multithreaded Programming Language
License:        GPL-2.0-or-later OR LGPL-2.1-or-later OR MIT
Group:          Development/Languages/Other
URL:            https://qore.org
Source0:        https://github.com/qorelanguage/qore/releases/download/release-%{version}/%{name}-%{version}.tar.bz2#/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE bmwiedemann boo#1084909
Patch0:         reproducible.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  bzip2
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex >= 2.5.31
BuildRequires:  gcc-c++ >= 4.8.1
BuildRequires:  gmp-devel
BuildRequires:  libbz2-devel
BuildRequires:  libtool
BuildRequires:  mpfr-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
Requires:       %{_bindir}/env
Requires(post): shared-mime-info
Requires(postun):shared-mime-info
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Qore is a scripting language supporting threading and embedded logic.
It applies a scripting-based approach to interface development and
can also be used as a general purpose language.

%if 0%{?suse_version}
%endif

%package -n libqore12
Summary:        Libraries for the qore runtime and qore clients
License:        GPL-2.0-or-later OR LGPL-2.0-or-later OR MIT
Group:          Development/Languages/Other
Provides:       qore-module(abi)%{?_isa} = 1.3
Provides:       qore-module(abi)%{?_isa} = 1.4
%if "%{libname}" == "libqore"
Provides:       libqore12 = %{version}
Obsoletes:      libqore-stdlib
Obsoletes:      libqore12 < %{version}
%endif

%description -n libqore12
Qore is a scripting language supporting threading and embedded logic.
It applies a scripting-based approach to interface development and
can also be used as a general purpose language.

This package provides the qore library required for all clients using qore
functionality.

%files -n libqore12
%defattr(-,root,root,-)
%{_libdir}/libqore.so.12.4.1
%{_libdir}/libqore.so.12
%doc README.md README-MODULES RELEASE-NOTES AUTHORS ABOUT
%license COPYING.LGPL COPYING.GPL COPYING.MIT README-LICENSE

%post -n libqore12 -p /sbin/ldconfig
%postun -n libqore12 -p /sbin/ldconfig

%package doc
Summary:        API documentation, programming language reference, and Qore example programs
License:        GPL-2.0-or-later OR LGPL-2.1-or-later OR MIT
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides the HTML documentation for the Qore programming language
and also for user modules delivered with Qore and also example programs.

%files doc
%defattr(-,root,root,-)
%doc docs/lang docs/modules/* examples/
%license COPYING.LGPL COPYING.GPL COPYING.MIT README-LICENSE

%package devel
Summary:        Header files needed to compile programs using the qore library
License:        GPL-2.0-or-later OR LGPL-2.0-or-later OR MIT
Group:          Development/Languages/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description devel
Qore is a scripting language supporting threading and embedded logic.
It applies a scripting-based approach to interface development and
can also be used as a general purpose language.

This package provides header files needed to compile client programs using the
Qore library.

%files devel
%defattr(-,root,root,-)
/usr/bin/qpp
/usr/bin/qdx
/usr/bin/qjar
%{_libdir}/libqore.so
%{_libdir}/pkgconfig/qore.pc
%dir %{_libdir}/cmake
%{_libdir}/cmake/Qore
%{_includedir}/*
%{mydatarootdir}/qore
%{mydatarootdir}/qore/*

%package devel-doc
Summary:        C++ API documentation for the qore library
License:        GPL-2.0-or-later OR LGPL-2.1-or-later OR MIT
Group:          Documentation
Requires:       libqore12 = %{version}-%{release}
BuildArch:      noarch

%description devel-doc
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides HTML documentation for the C++ API for the Qore library.

%files devel-doc
%defattr(-,root,root,-)
%doc docs/library/html/*

%package misc-tools
Summary:        Miscellaneous user tools writen in Qore Programming Language
License:        GPL-2.0-or-later OR LGPL-2.0-or-later OR MIT
Group:          Development/Tools/Other
Requires:       qore = %{version}-%{release}
BuildArch:      noarch

%description misc-tools
This package contains tool for working with:
 - REST APIs
 - SQL Databases

%files misc-tools
%defattr(-,root,root,-)
%{_bindir}/qdp
%{_bindir}/qget
%{_bindir}/rest
%{_bindir}/sfrest
%{_bindir}/saprest
%{_bindir}/sqlutil
%{_bindir}/schema-reverse

%prep
%autosetup -p1

# silence the executable warning for examples
find examples -type f -exec chmod -x {} \;

%build
aclocal
autoreconf -fi
%if "%_lib" == "lib64"
c64=--enable-64bit
%endif
%configure --disable-debug --disable-static $c64
make %{?_smp_mflags}
sed -i '1s,#!/usr/bin/env qore,#!/usr/bin/qore,' bin/* doxygen/qdx doxygen/qjar

%install
mkdir -p %{buildroot}%{_prefix}/bin
mkdir -p %{buildroot}/%{module_dir}/%{version}
mkdir -p %{buildroot}%{_prefix}/man/man1
make install prefix=%{_prefix} DESTDIR=%{buildroot}
rm %{buildroot}/%{_libdir}/libqore.la
%fdupes -s docs

%check
export QORE_MODULE_DIR=qlib
./qore examples/test/qore/threads/background.qtest
./qore examples/test/qore/threads/deadlock.qtest
./qore examples/test/qore/threads/max-threads-count.qtest
./qore examples/test/qore/threads/set_thread_init.qtest
./qore examples/test/qore/threads/thread-object.qtest
./qore examples/test/qore/threads/thread-resources.qtest
./qore examples/test/qore/threads/tld.qtest

%post
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null

%postun
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null

%files
%defattr(-,root,root,-)
%{_bindir}/qore
%{_bindir}/qdbg*
%{module_dir}
%dir %{_datadir}/qore-modules
%{_datadir}/qore-modules/%{version}
%{_mandir}/man1/qore.1.*

%changelog
* Sun May 26 2024 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.19.2
  * requires libqore.so.12.4.1
  * libqore-stdlib package moved to qore package
  * Added the HueRestClient class
  * Implemented the GoogleRestClient module
  * Implemented a logger interface class
  * Fixed reporting URLs for invalid connections
  * Fixed non-blocking I/O checking for a connect on Darwin
  * Added connection features to connection info
  * Allow user modules included with external binary modules
  * Fixed compatibility with recent versions of ServiceNow
  * Added missing allowed values to field data info
  * Fixed a bug where an access exception could be raised
  * Fixed bug with http connection context leak
  * Fixed setting the varargs flag on user variants
  * Fixed returning the OAuth2 token URL
  * Fixed REST headers in the SalesforceRestClient module
  * Fixed a bug setting the time zone on macOS Sonoma
  * Fixed conversions of soft bool, binary, float, int
  * CSV writer automatically detects output fields
  * Fixed a race condition that could cause an exception
  * Fixed trunc handling in the mapper when bulk processing
  * Fixed mappings with default values and outout field types
  * Fixed adding, updating, and removing connections
  * Fixed support for nullable object props
  * Fixed deadlocks in polling connection monitoring
  * Added the encode_chars HTTP / REST option
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Sep  2 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.18.1
  * Added the ElasticSearchDataProvider module + tests
  * Fixed TID assignments after all TIDs have been assigned
  * Implemented support for ellipses in Qore
  * Implemented options to allow some badly-formatted Swagger
  * Set the default connect timeout for HTTP connection
  * Implemented an initial EmpathicBuildingDataProvider module
  * Fixed date subtraction when the RHS is 1970-01-01Z
  * Fix compilation of QoreEllipsesNode during non-scu
  * Verify connection option values against allowed_values
  * Fixed a bug where the HttpConnection scheme could not be used
  * Allow user modules included with external binary modules
  * Fixed compatibility with recent versions of ServiceNow
  * Fixed operator handling in ServiceNow searches
  * Fixed URI path reporting in REST error messages
  * Added missing allowed values to field data info
* Fri Jul 21 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Fix qore-stdlib configuration
* Tue Jul 18 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.16.1
  * Add include/qore/macros-riscv.h to include_HEADERS
  * fixed a bug in parse_datasource() parsing option values
  * added support for a new DBI driver method
  * Feature/4684 jdbc drivers
  * fixed setting connection status to OK
  * allow auth headers to be set with WebSocket client connect
  * fixed a deadlock when the WebSocketClient goes out of scope
  * allow data provider hierarchy to be browsed
  * use delayed observable classes from factories
  * Schema module does not report changes with negative verbose values
  * added support for MS SQL Server DBs with the DataProvider
  * ensure that exception attributes from ping errors
  * Make more PowerPC platforms use the PowerPC macros
  * added generic search capabilities to DbDataProvider
  * fixed a bug in hash assignments in HashDataType
  * fixed ws client data providers to allow initialization
  * fixed a bug reloading certs on running listeners
  * added missing transaction flag to connection info for data
  * fixed connection options
  * allow handler information to be returned
* Tue Jan 24 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Remove buildroot from mydatarootdir
* Mon Jan 16 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.13.0
  * implemented support for including REST path args
  * fixed a bug handling the swagger_base_path RestClient option
  * RestHandler will always set the socketobject request content
  * implemented get_safe_url()
  * fixed parse_url() with passwords with / chars in it
  * fixed handling child attributes in connection objects
  * fixed REST ping operations
  * fixed bugs in HTTP communications with 32-bit builds of Qore
* Thu Dec  8 2022 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.12.4
  * fixed a bug building documentation with autotools
  * fixed bugs in C++ QoreSocket::send*() methods not used in the Qore
    language
  * fixed a bug building documentation with release files created from
    the autotools makefile target
  * fixed bugs in the cmake configuration generating documentation for
    builtin modules
  * provide APIs to provide additional information about child data
  * Bugfix/4545 swagger fix
  * Add support for RISC-V
  * Bugfix/4538 sqlutil expressions
  * refs #4550 fixed WebUtil to never serve files outside the root dir
  * refs #4553 fixed a bug building with openssl 3+
  * refs #4555 do not return / chars in data provider names
  * refs #4557 implemented support for event handling in DataProviders
  * refs #4559 fixed FsUtil to behave more consistently regarding target
  * refs #4561 fixed bugs handling escape chars in regex subst replacement
  * refs #4565 fixed WebSocket PING/PONG handling
  * refs #4567 fixed bugs in HTTPClient class setting keys and certs
  * refs #4572 added child capability indicator attributes to data
  * refs #4574 allow HTTP certs to be reloaded from the source location
  * refs #4576 DataProvider module: updated child capability info
  * refs #4578 added the argument hash to methods returning REST API path
  * refs #4583 fixed race conditions in the Logger module
  * refs #4587 fixed a bug setting the data provider name in Swagger schema
  * refs #4590 QUnit: allow the exception argument to be checked
  * refs #4595 working socket polling infrastructure
  * refs #4605 fixed handling abstract memberGate() and methodGate() methods
  * refs #4607 fixed the unreferenced-variable warning
  * refs #4609 fixed cast<> with lvalues
  * added OdbcFirebirdSqlUtil module
  * refs #4620 fixed bugs serializing / deserializing SqlUtil tables
  * refs #4622 fixed AbstractDataProvider::search*() methods
  * Bugfix/4624 data provider search fix
  * refs #4626 added support for the immediate data:// location
  * refs #4628 fixed sequence* mapper keys in DbTableDataProvider
  * Bugfix/4624 4632 fixes
  * refs #4634 fixed WebSocketHandler::sendOne()
  * refs #4637 allow information about schema changes after alignments
  * refs #4639 allow for the client's time zone to be set
  * refs #4643 fixed handling signal args
  * refs #4646 allow REST handlers to set custom headers in error responses
  * refs #4658 fixed a race condition in deadlock detection
  * Enablement of the architecture s390x
  * Move qore-doc.spec to qore.spec
  * Remove fix-logger-doc.patch and fix-building-doc.patch
  * Remove clean section because of integration in rpm
* Sun Jun  5 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.8.0
  * Updated modules with initial support for generic expressions for
    searches
  * Addded support for data provider options to support default values
  * Addded search_operators to the data provider response to report
    supported search operators
  * Fixed a type error in DataProvider::search*() calls with an empty
    where hash argument
  * RestClient module
  * Fixed a bug where REST schema validation was not applied in all
    contexts with specialized REST clients
  * RestHandler module
  * Do not raise a validation error when a response with an unknown
    code has a message body; this hides the true error message from
    the caller in case of error messages
  * Allow a logger to be set in validators
  * ServiceNowRestDataProvider module
  * Fixed bugs handling the orderby, orderbydesc, and groupby search
    options
  * Fixed a bug where the cast<>() operator threw parse-time exceptions
    with hashdecls that could succeed at runtime
  * Fixed a bug handling types at parse time with the minus operator and
    complex hash operands
  * Fixed a static memory leak in libqore shutting down the library when
    built with openssl 3+
  * Fixed a bug where HTTP redirect messages were encoded twice causing
    redirect failures in cases where the redirect URI path had encoded
    elements
  * Fixed a crash related to stack exhaustion resolving deeply-nested
    references
- Add fix-building-doc.patch
- Add fix-logger-doc.patch
- Update to version 1.7.2
  * Fixed parse_datasource() to parse datasource strings with a DB name
    as a path or with ':' chars in the DB or host name
- Update to version 1.7.1
  * DataProvider module: made it possible to determine the default field
    type in HashDataType
  * FsUtil module: fixed join_paths() to handle an arbitrary number of
    paths as arguments (the most common use case)
  * RestHandler module: improved error handling and sending error messages
    when exceptions contain non-serializable objects
  * Fixed a bug handling reference assignments and calculating matches
    with overloaded functions and methods
  * Fixed a bug with compilers that do not guarantee left to right argument
    execution order such as g++ 12+; note that the C++ standard does not
    guarantee this in any case
  * Fixed cast<> operator handling of "or nothing" types at parse and runtime
  * Load the default provider with OpenSSL3+ to make it work on platforms
    where this provider is not automatically loaded
- Update to version 1.6.0
  * DataProvider module: added the desc key supporting a markdown description
    to data provider info
  * Mapper module: implemented options supporting suppressing data provider
    calls on input and output
  * Added HTTPClient::getSafeURL() and HTTPClient::getSafeProxyURL()
- Update to version 1.5.0
  * CsvUtil and FixedLengthUtil: added support for resolving locations
    with the FileLocationHandler module
  * DataProvider module:fixed a type error iterating data in
    DefaultBulkRecordIterface
* Sun Jun  5 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.4.0
  * DataProvider module
  * Added support for tags on data provider types
  * Fixed data provider factory info to provide info about the
    actual data provider factory instead of only provider info
  * Added "from example" APIs to data provider factories
  * Added generic search capabilities to data providers with no
    native search functionality
  * Util module:
  * Implemented the serialize_to_string() API
  * parse_uri_query() fails if the string has newlines in it
  * RestHandler module: Added missing make*() methods with REST
    responses to the RestHandler class
  * added the CipherMap constant providing a hash of known ciphers
  * Support for OpenSSL 3+ added
  * when Qore is compiled with OpenSSL3 or greater, all cipher
    and digest algorithms known to the encryption library are
    supported with dynamic APIs
  * Removed code that generated unnecessary ILLEGAL-CALL
    exceptions at parse time
- Update to version 1.3.0
  * FileLocationHandler module
  * updated for read/write operations and added streaming APIs
  * Added an optional encoding parameter to the FtpClient::getAsString() API
  * Fixed a bug handling committing parse operations where final
    checks were not always made before committing
  * Fixed return type for Type::isAssignableFrom(Type) in the
    reflection module
  * Fixed bugs in variant matching that could lead to unexpected
    results at runtime as well as errors with inherited Java code
  * Fixed a bug dispatching method and function calls at runtime in
    certain cases
- Update to version 1.2.0
  * DataProvider module
  * Added a logger to the AbstractDataProvider class to enable
    logging
  * Added support for creating, updating, and deleting data providers
  * DbDataProvider module
  * Added support for creating, updating, and deleting data providers
  * FreetdsSqlUtil module
  * Fixed a bug where offset and limit were not properly supported
    with MS SQL Server DBs
  * Fixed a bug where date/time values in other time zones were not
    bound correctly
  * Fixed a bug handling transaction savepoints
  * Fixed a bug in certain type errors involving complex types where
    the specific complex type was omitted from the error message
  * Fixed a bug initializing constant values at parse time;
    now all constant expressions requiring evaluation are evaluated
    after all other parsing is done
- Update to version 1.1.0
  * Added DataProviderTypeCache::listParentTypes() to allow a list
    of parent types to be returned
  * Added StringOutputStream::hasData()
  * rethrow now accepts optional exception arguments to allow
    exceptions to be enriched in a catch block while maintaining
    the original call stack, and the on_error statement now includes
    an implicit argument $1 giving the currently-active exception,
    additionally, rethrow statements are now allowed in on_error
    statement blocks to allow for exception enrichment without
    requiring a try/catch block.
  * Fixed a bug in the stack guard implementation where additional
    guard area was needed in the primary thread on some platforms
  * Fixed bugs tagging functions and constants provided by builtin
    modules with their module name; required to consistently provide
    unique binary names when imported into Java, for example
  * Fixed a bug initializing constant values that could result in
    spurious errors
  * Added regex APIs to the C++ string class
  * Added a warning for constant operands with the square bracket
    operator that are not integers
  * Fixed a bug handling EOF conditions while parsing the final
    part of regular expressions
* Fri May 20 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.0.13
  * Fixed: builtin namespaces are not consistently tagged with the
    providing module's name
  * Update QUnit constructor variants taking list arguments to allow
    them to work better with Python and Java subclasses
  * Fixed: not possible to use a Mapper with an output provider only
    for the output data type
  * Fixed a bug where qpp would not recognize multi-line method
  * Fixed a regression in the SwaggerDataProvider
- Update to version 1.0.12
  * Fixed handling implicit in-object calls in arguments
  * Adding missing methods for transaction management with
    supported DataProviders
  * Fixed upsert usage with unique constraints and indices
    when there is a non-matching PK
  * Fixed handling reserved words as column names in the
    PgsqlSqlUtil module
  * Fixed a bug in parse_to_qore_value() with floats and numbers
    with trailing zeros
  * Fixed handling recursive references in Swagger schemas in the
    Swagger module
  * Fixed handling recursive references in Swagger schemas in the
    SwaggerDataProvider module
  * Mail and MailMessage fixes - downstream patches
- Drop upstream fixed fix-module-linker-flags.patch
* Thu Oct 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.0.10:
  * Might break backwards compatibility:
  * Some server-side APIs have changed (integration of the Logger
    module in the HttpServer and the HttpServerUtil modules).
  * Implemented the invalid-catch warning when types are required
    by parse options and added to the default warning mask for modules
  * Added support for thread-local global variables
  * Type errors with function and method resolution will report the full
    namespace paths of class and hashdecl types
  * ConnectionProvider module:
  * updated the AbstractConnection::getInfo() method
  * added the AbstractConnection::getExtendedInfo() method
  * DataProvider module:
  * added the limit search option to the DefaultRecordIterator class
  * HttpServer module:
  * allow dynamic handlers to be disabled before being removed
  * integrated the Logger module
  * removed deprecated APIs
  * HttpServerUtil module:
  * integrated the Logger module
  * Logger module:
  * added support for the %%h and %%P patterns for hostname and PID
  * allow file appenders to be reopened
  * enable serialization for LoggerEvent objects as well as for
    them to be submitted directly to Logger objects
  * Added qjar tool for exporting javadoc
  * Many bug fixes
  * Full release notes:
    https://docs.qore.org/qore-1.0.10/lang/html/release_notes.html
- Add fix-module-linker-flags.patch fixing gh#4335
* Sat Jun 12 2021 Jan Engelhardt <jengelh@inai.de>
- Trim marketing wording from description.
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.15
  * DataProvider: Fixed a bug where the data type was not supported
    correctly as a data provider type
  * Fixed a potential crash when raising a large number of exceptions
  * Fixed a potential deadlock loading user modules with complex
    initialization code
  * Fixed a bug where SSL errors were not properly cleared before
    I/O operations in all cases
  * Fixed a bug where empty binary values could not be deserialized
  * Fixed handling Qore program destruction in a foreign thread in
    a binary module that could cause a crash
- Fixed abi Provides generation
* Wed May 19 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.14
  * OracleSqlUtil module and SqlUtil module: fixed various SQL
    generation issues
  * Swagger module: fixed a bug where unknown string format types
    were not ignored but instead caused an exception to be thrown
  * Util module: fixed a bug in parse_memory_size()
  * Full changes:
    https://docs.qore.org/qore-0.9.14/lang/html/release_notes.html
* Wed Apr 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.9.13
  * Fixes CVE-2020-13615
  * Added saprest tool (a SAP rest client)
  * Bug fixes and improvements for
  * CsvUtil
  * DataProvider
  * FixedLengthUtil
  * HttpServer nad HttpServerUtil
  * ServiceNowRestDataProvider
  * WebUtil
  * RestClient: additional fixes to REST path handling with schema
    validators with a base path
  * New Modules in Qore:
  * ServiceNowRestClient: provides APIs for communicating with
    the ServiceNow REST API
  * ServiceNowRestDataProvider: Provides a data provider API
    for the ServiceNow REST API
  * https://docs.qore.org/qore-0.9.13/lang/html/release_notes.html
- ABI breaks with 0.9.0 update, removed outdated API and updated
  qore-module.prov
- Refreshed reproducible.patch
- Drop unused qore-libtool-2.4.6.patch
- Split -doc package, building the documentation requires the
  yaml module, so this would create a dependency circle
* Mon Aug  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Make the qore-module-api-* provides more fail prove: store the
  provides list in qore-module.prov. During build, this file is
  auto-generated and compared against the package provided one to
  ensure the list is correct.
* Thu Jul 12 2018 bwiedemann@suse.com
- Add reproducible.patch to not include build hostname in package
  to make build reproducible (boo#1084909)
* Thu Oct 12 2017 jengelh@inai.de
- Rework scriptlets for ldconfig. Adjust RPM groups.
  Avoid double-shipping of files. Use %%configure.
* Fri Sep 29 2017 petr@yarpen.cz
- updated to 0.8.13
- Input/Output stream APIs
- Vastly improved type system with complex type support
  Improved operators; list, string, binary slice operators,
  the ".." range operator, improved new, cast<>, and
  instanceof operators, lazy evaluation of functional and
  list operators, more
- Improved encryption support including AES encryption,
  encryption/decryption streams, support for AAD and MACs
  Improved HTTPS and SSL security support with addition
  X.509 certificate support including automatic certificate
  verification in client and server contexts
- Universal connection API
- Support for binding output placeholder buffers for result
  sets that return an SQLStatement object for more efficient
  piecewise processing of DB stored procedure/function calls
  that return very large result sets
- Strong encapsulation support (ex: private:internal)
- Deterministic garbage collection performance improvements
  with large cycles
- Debugging support and APIs including remote network debugging
- Language Server Protocol support for Qore in the new astparser
  module for rich language support in IDEs such as the Visual
  studio Code Qore Extension
- much more
- rpm: /usr/bin user programs are part of qore-misc-tools package
  now as it was suggested by advanced packagers on IRC
- rpm: updated qore-libtool-2.4.6.patch for new release
* Thu Sep  8 2016 petr@yarpen.cz
- updated to 0.8.12.1
- removed un-applicable patches: configure.patch
* Fri Jun 12 2015 dimstar@opensuse.org
- Add qore-libtool-2.4.6.patch: Remove imported Libtool 2.4.2
  macros from acinclude.m4: this is a terrible hack by upstream to
  not forcibly depend on libtool >= 2.4.2, which has a very bad
  side effect now with libtool 2.4.6 available: the macros conflict
  due the internal API changes inside libtool.
* Sun Jul 13 2014 schwab@linux-m68k.org
- configure.patch: don't use -m32/-m64
* Fri Jun 20 2014 petr@yarpen.cz
- updated to 0.8.11
* Fri Dec 14 2012 petr@yarpen.cz
- spec file reformatted to fit OBS rules
* Thu Nov  8 2012 david@qore.org
- updated to 0.8.6.2
* Fri Oct 26 2012 david@qore.org
- updated to 0.8.6.1
* Sat Sep  1 2012 david@qore.org
- updated to 0.8.6
* Tue May 22 2012 david@qore.org
- updated to 0.8.5
* Mon May 21 2012 david@qore.org
- updated for new doxygen-based documentation, added devel-doc pkg
  for API docs
- updated package descriptions
* Wed Oct 19 2011 david@qore.org
- updated to 0.8.4
* Thu Oct  6 2011 petr.vanek@qoretechnologies.com
- pkg-config
* Sat Mar  5 2011 david@qore.org
- updated to 0.8.3
* Sat Dec 25 2010 david@qore.org
- updated to 0.8.2
* Mon Jun 14 2010 david@qore.org
- updated to 0.8.1
* Tue Nov 17 2009 david_nichols@users.sourceforge.net
- updated to 0.8.0
* Thu Nov  5 2009 david_nichols@users.sourceforge.net
- updated to 0.7.7
* Sun Jul 12 2009 david_nichols@users.sourceforge.net
- updated to 0.7.6
* Sun Jun 21 2009 david_nichols@users.sourceforge.net
- updated to 0.7.5
* Tue Mar  3 2009 david_nichols@users.sourceforge.net
- updated to 0.7.4
* Tue Dec  2 2008 david_nichols@users.sourceforge.net
- updated to 0.7.3
* Tue Nov 25 2008 david_nichols@users.sourceforge.net
- made libqore* the default name for lib package, removed la file
* Sat Nov 22 2008 david_nichols@users.sourceforge.net
- updated to 0.7.2
* Sun Oct 12 2008 david_nichols@users.sourceforge.net
- fixed devel pacakges for suse
* Mon Oct  6 2008 david_nichols@users.sourceforge.net
- released 0.7.0
* Wed Sep  3 2008 david_nichols@users.sourceforge.net
- removed all modules as they are now independent projects
* Mon Sep  1 2008 david_nichols@users.sourceforge.net
- fixed dist tag for suse distributions
- updated for new module directory, added qore-module-api-*
  capability
* Sun Jul 13 2008 david_nichols@users.sourceforge.net
- copied improvements from opensuse rpm and updated based
  on rpmlint output
- updated version to 0.7.0
* Fri Jun 13 2008 david_nichols@users.sourceforge.net
- fixed spec file to support more architectures
* Thu Apr 10 2008 david_nichols@users.sourceforge.net
- updated package to 0.6.2.4 and disabled mssql module build due
- to lack of freetds packages in the build service :-(
* Sun Oct 15 2006 mrueckert@suse.de
- added --enable-64bit to build properly on 64bit biarch
* Sun Oct 15 2006 mrueckert@suse.de
- initial package of 0.5.3
